pub struct ProviderClient<R, W> { /* private fields */ }Expand description
Async client for communicating with a key provider process.
Thread-safe via an interior Mutex — multiple tasks can share a single client,
but requests are serialized (one at a time on the wire).
Implementations
Sourceimpl<R, W> ProviderClient<R, W>
impl<R, W> ProviderClient<R, W>
Sourcepub fn new(reader: R, writer: W) -> Self
pub fn new(reader: R, writer: W) -> Self
Create a new client from an AsyncRead (provider’s stdout) and AsyncWrite (provider’s stdin).
Sourcepub async fn initialize(&self) -> Result<InitializeResult, Error>
pub async fn initialize(&self) -> Result<InitializeResult, Error>
Send an initialize request and return the provider’s certificates.
May be called multiple times to reload certificates from a running provider.